Module twilight_model::application::callback
source · [−]Expand description
Used when responding to interactions.
Structs
Response to an autocomplete Interaction.
Optional extra data sent when responding to an Interaction of type
ApplicationCommand.
Enums
Payload used for responding to an interaction.
Contains the possible response type integers for an interaction.