pub enum InteractionResponse {
Pong,
ChannelMessageWithSource(CallbackData),
DeferredChannelMessageWithSource(CallbackData),
DeferredUpdateMessage,
UpdateMessage(CallbackData),
Autocomplete(Autocomplete),
}Expand description
Payload used for responding to an interaction.
Variants
Pong
Used when responding to an interaction of type Ping.
ChannelMessageWithSource(CallbackData)
Responds to an interaction with a message.
DeferredChannelMessageWithSource(CallbackData)
Acknowledges an interaction, showing a loading state.
DeferredUpdateMessage
Acknowledge an interaction and edit the original message later.
This is only valid for components.
UpdateMessage(CallbackData)
Edit the message a component is attached to.
Autocomplete(Autocomplete)
Autocomplete results.
Implementations
sourceimpl InteractionResponse
impl InteractionResponse
sourcepub const fn kind(&self) -> ResponseType
pub const fn kind(&self) -> ResponseType
Type of response this is.
Examples
Check the types of the DeferredUpdateMessage and Pong
interaction response variants.
use twilight_model::application::callback::{
InteractionResponse,
ResponseType,
};
assert_eq!(
ResponseType::DeferredUpdateMessage,
InteractionResponse::DeferredUpdateMessage.kind(),
);
assert_eq!(ResponseType::Pong, InteractionResponse::Pong.kind());Trait Implementations
sourceimpl Clone for InteractionResponse
impl Clone for InteractionResponse
sourcefn clone(&self) -> InteractionResponse
fn clone(&self) -> InteractionResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for InteractionResponse
impl Debug for InteractionResponse
sourceimpl<'de> Deserialize<'de> for InteractionResponse
impl<'de> Deserialize<'de> for InteractionResponse
sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for InteractionResponse
impl Hash for InteractionResponse
sourceimpl PartialEq<InteractionResponse> for InteractionResponse
impl PartialEq<InteractionResponse> for InteractionResponse
sourcefn eq(&self, other: &InteractionResponse) -> bool
fn eq(&self, other: &InteractionResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &InteractionResponse) -> bool
fn ne(&self, other: &InteractionResponse) -> bool
This method tests for !=.
sourceimpl Serialize for InteractionResponse
impl Serialize for InteractionResponse
impl Eq for InteractionResponse
impl StructuralEq for InteractionResponse
impl StructuralPartialEq for InteractionResponse