Enum twilight_model::application::callback::ResponseType
source · [−]#[repr(u8)]
pub enum ResponseType {
Pong,
ChannelMessageWithSource,
DeferredChannelMessageWithSource,
DeferredUpdateMessage,
UpdateMessage,
ApplicationCommandAutocompleteResult,
}Expand description
Contains the possible response type integers for an interaction.
Variants
Pong
ChannelMessageWithSource
DeferredChannelMessageWithSource
DeferredUpdateMessage
Ack an interaction and edit the original message later.
This is only valid for components.
UpdateMessage
Edit the message a component is attached to.
ApplicationCommandAutocompleteResult
Respond to an autocomplete interaction with suggested choices.
Implementations
sourceimpl ResponseType
impl ResponseType
sourcepub const fn name(self) -> &'static str
pub const fn name(self) -> &'static str
Name of the variant.
The returned name is equivalent to the variant name.
Examples
Check the names of the Pong and UpdateMessage variants:
use twilight_model::application::callback::ResponseType;
assert_eq!("Pong", ResponseType::Pong.name());
assert_eq!("UpdateMessage", ResponseType::UpdateMessage.name());Trait Implementations
sourceimpl Clone for ResponseType
impl Clone for ResponseType
sourcefn clone(&self) -> ResponseType
fn clone(&self) -> ResponseType
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ResponseType
impl Debug for ResponseType
sourceimpl<'de> Deserialize<'de> for ResponseType
impl<'de> Deserialize<'de> for ResponseType
sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ResponseType
impl Hash for ResponseType
sourceimpl Ord for ResponseType
impl Ord for ResponseType
sourceimpl PartialEq<ResponseType> for ResponseType
impl PartialEq<ResponseType> for ResponseType
sourceimpl PartialOrd<ResponseType> for ResponseType
impl PartialOrd<ResponseType> for ResponseType
sourcefn partial_cmp(&self, other: &ResponseType) -> Option<Ordering>
fn partial_cmp(&self, other: &ResponseType) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for ResponseType
impl Serialize for ResponseType
impl Copy for ResponseType
impl Eq for ResponseType
impl StructuralEq for ResponseType
impl StructuralPartialEq for ResponseType