Struct twilight_model::application::callback::CallbackData
source · [−]pub struct CallbackData {
pub allowed_mentions: Option<AllowedMentions>,
pub components: Option<Vec<Component>>,
pub content: Option<String>,
pub embeds: Option<Vec<Embed>>,
pub flags: Option<MessageFlags>,
pub tts: Option<bool>,
}Expand description
Optional extra data sent when responding to an Interaction of type
ApplicationCommand.
This is used when intending to send a message in the response.
This struct has an associated builder in the twilight-util crate.
Fields
allowed_mentions: Option<AllowedMentions>components: Option<Vec<Component>>List of components to include in the callback response.
content: Option<String>embeds: Option<Vec<Embed>>flags: Option<MessageFlags>tts: Option<bool>Trait Implementations
sourceimpl Clone for CallbackData
impl Clone for CallbackData
sourcefn clone(&self) -> CallbackData
fn clone(&self) -> CallbackData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for CallbackData
impl Debug for CallbackData
sourceimpl<'de> Deserialize<'de> for CallbackData
impl<'de> Deserialize<'de> for CallbackData
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for CallbackData
impl Hash for CallbackData
sourceimpl PartialEq<CallbackData> for CallbackData
impl PartialEq<CallbackData> for CallbackData
sourcefn eq(&self, other: &CallbackData) -> bool
fn eq(&self, other: &CallbackData) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &CallbackData) -> bool
fn ne(&self, other: &CallbackData) -> bool
This method tests for !=.
sourceimpl Serialize for CallbackData
impl Serialize for CallbackData
impl Eq for CallbackData
impl StructuralEq for CallbackData
impl StructuralPartialEq for CallbackData