Struct twilight_model::application::command::permissions::CommandPermission
source · pub struct CommandPermission {
pub id: CommandPermissionType,
pub permission: bool,
}Expand description
Member, channel or role explicit permission to use a command.
Fields
id: CommandPermissionTypeAffected resource.
permission: boolWhether the resource is allowed or disallowed to use the command.