Struct twilight_model::application::command::ChoiceCommandOptionData [−][src]
pub struct ChoiceCommandOptionData {
pub choices: Vec<CommandOptionChoice>,
pub description: String,
pub name: String,
pub required: bool,
}Expand description
Data supplied to a CommandOption of type String or Integer.
Fields
choices: Vec<CommandOptionChoice>Predetermined choices may be defined for a user to select.
When completing this option, the user is prompted with a selector of all available choices.
description: StringDescription of the option. It must be 100 characters or less.
name: StringName of the option. It must be 32 characters or less.
required: boolWhether or not the option is required to be completed by a user.