Struct twilight_model::application::component::button::Button
source · [−]pub struct Button {
pub custom_id: Option<String>,
pub disabled: bool,
pub emoji: Option<ReactionType>,
pub label: Option<String>,
pub style: ButtonStyle,
pub url: Option<String>,
}Expand description
Clickable interactive components that render on messages.
Fields
custom_id: Option<String>User defined identifier for the button.
This field is required when using the following ButtonStyles:
disabled: boolWhether the button is disabled.
Defaults to false.
emoji: Option<ReactionType>Visual emoji for clients to display with the button.
label: Option<String>Text appearing on the button.
style: ButtonStyleStyle variant of the button.
url: Option<String>URL for buttons of a ButtonStyle::Link style.