Enum twilight_model::application::interaction::application_command::CommandDataOption [−][src]
pub enum CommandDataOption {
String {
name: String,
value: String,
},
Integer {
name: String,
value: i64,
},
Boolean {
name: String,
value: bool,
},
SubCommand {
name: String,
options: Vec<CommandDataOption>,
},
}Expand description
Data received when a user fills in a command option.
Note: user, channel, role, and mentionable option types will be returned as
a String option here.
Refer to the discord docs for more information.
Variants
Show fields
Fields of SubCommand
name: Stringoptions: Vec<CommandDataOption>Implementations