pub struct ApplicationCommand {
    pub application_id: Id<ApplicationMarker>,
    pub channel_id: Id<ChannelMarker>,
    pub data: CommandData,
    pub guild_id: Option<Id<GuildMarker>>,
    pub guild_locale: Option<String>,
    pub id: Id<InteractionMarker>,
    pub kind: InteractionType,
    pub locale: String,
    pub member: Option<PartialMember>,
    pub token: String,
    pub user: Option<User>,
}
Data present in an Interaction of type ApplicationCommand.

Fields

application_id: Id<ApplicationMarker>

ID of the associated application.

channel_id: Id<ChannelMarker>

ID of the channel the interaction was invoked in.

data: CommandData

Data from the invoked command.

guild_id: Option<Id<GuildMarker>>

ID of the guild the interaction was invoked in.

guild_locale: Option<String>

Guild’s preferred locale.

Present when the command is used in a guild.

Defaults to en-US.

id: Id<InteractionMarker>

ID of the interaction.

kind: InteractionType

Kind of the interaction.

Should always be InteractionType::ApplicationCommand.

locale: String

Selected language of the user who invoked the interaction.

member: Option<PartialMember>

Member that invoked the interaction.

Present when the command is used in a guild.

token: String

Token of the interaction.

user: Option<User>

User that invoked the interaction.

Present when the command is used in a direct message.

Implementations

ID of the user that invoked the interaction.

This will first check for the member’s user’s ID and, if not present, then check the user’s ID.

Whether the interaction was invoked in a DM.

Whether the interaction was invoked in a guild.