pub struct CommandData {
pub id: Id<CommandMarker>,
pub name: String,
pub kind: CommandType,
pub options: Vec<CommandDataOption>,
pub resolved: Option<CommandInteractionDataResolved>,
pub target_id: Option<Id<GenericMarker>>,
}Expand description
Data received when an ApplicationCommand interaction is executed.
Fields
id: Id<CommandMarker>ID of the command.
name: StringName of the command.
kind: CommandTypeType of the command.
options: Vec<CommandDataOption>List of parsed options specified by the user.
resolved: Option<CommandInteractionDataResolved>Data sent if any of the options are Discord types.
target_id: Option<Id<GenericMarker>>If this is a user or message command, the ID of the targeted user/message.