pub struct InteractionMember {
pub avatar: Option<String>,
pub communication_disabled_until: Option<Timestamp>,
pub joined_at: Timestamp,
pub nick: Option<String>,
pub pending: bool,
pub permissions: Permissions,
pub premium_since: Option<Timestamp>,
pub roles: Vec<Id<RoleMarker>>,
}Fields
avatar: Option<String>Member’s guild avatar.
communication_disabled_until: Option<Timestamp>joined_at: Timestampnick: Option<String>pending: boolWhether the user has yet to pass the guild’s Membership Screening requirements.
permissions: PermissionsTotal permissions of the member in this channel including overwrites
roles: Vec<Id<RoleMarker>>Trait Implementations
sourceimpl Clone for InteractionMember
impl Clone for InteractionMember
sourcefn clone(&self) -> InteractionMember
fn clone(&self) -> InteractionMember
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for InteractionMember
impl Debug for InteractionMember
sourceimpl<'de> Deserialize<'de> for InteractionMember
impl<'de> Deserialize<'de> for InteractionMember
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<InteractionMember> for InteractionMember
impl PartialEq<InteractionMember> for InteractionMember
sourcefn eq(&self, other: &InteractionMember) -> bool
fn eq(&self, other: &InteractionMember) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &InteractionMember) -> bool
fn ne(&self, other: &InteractionMember) -> bool
This method tests for !=.
sourceimpl Serialize for InteractionMember
impl Serialize for InteractionMember
impl Eq for InteractionMember
impl StructuralEq for InteractionMember
impl StructuralPartialEq for InteractionMember