Struct twilight_model::application::interaction::application_command_autocomplete::ApplicationCommandAutocomplete
source · [−]pub struct ApplicationCommandAutocomplete {
pub application_id: Id<ApplicationMarker>,
pub channel_id: Id<ChannelMarker>,
pub data: ApplicationCommandAutocompleteData,
pub guild_id: Option<Id<GuildMarker>>,
pub guild_locale: Option<String>,
pub id: Id<InteractionMarker>,
pub kind: InteractionType,
pub locale: String,
pub member: Option<PartialMember>,
pub token: String,
pub user: Option<User>,
}Expand description
Data present in an Interaction of type ApplicationCommandAutocomplete.
Fields
application_id: Id<ApplicationMarker>ID of the associated application.
channel_id: Id<ChannelMarker>ID of the channel the interaction was invoked in.
data: ApplicationCommandAutocompleteDataData from the invoked command.
guild_id: Option<Id<GuildMarker>>ID of the guild the interaction was invoked in.
guild_locale: Option<String>Guild’s preferred locale.
Present when the command is used in a guild.
Defaults to en-US.
id: Id<InteractionMarker>ID of the interaction.
kind: InteractionTypeKind of the interaction.
Should always be InteractionType::ApplicationCommandAutocomplete.
locale: StringSelected language of the user who invoked the interaction.
member: Option<PartialMember>Member that invoked the interaction.
Present when the command is used in a guild.
token: StringToken of the interaction.
user: Option<User>User that invoked the interaction.
Present when the command is used in a direct message.
Implementations