Struct twilight_model::application::interaction::application_command_autocomplete::ApplicationCommandAutocompleteDataOption
source · [−]pub struct ApplicationCommandAutocompleteDataOption {
pub focused: bool,
pub kind: ApplicationCommandAutocompleteDataOptionType,
pub name: String,
pub options: Vec<ApplicationCommandAutocompleteDataOption>,
pub value: Option<String>,
}Expand description
Data received when a user partially fills in a command option.
Fields
focused: boolkind: ApplicationCommandAutocompleteDataOptionTypename: Stringoptions: Vec<ApplicationCommandAutocompleteDataOption>value: Option<String>Trait Implementations
sourceimpl Clone for ApplicationCommandAutocompleteDataOption
impl Clone for ApplicationCommandAutocompleteDataOption
sourcefn clone(&self) -> ApplicationCommandAutocompleteDataOption
fn clone(&self) -> ApplicationCommandAutocompleteDataOption
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'de> Deserialize<'de> for ApplicationCommandAutocompleteDataOption
impl<'de> Deserialize<'de> for ApplicationCommandAutocompleteDataOption
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<ApplicationCommandAutocompleteDataOption> for ApplicationCommandAutocompleteDataOption
impl PartialEq<ApplicationCommandAutocompleteDataOption> for ApplicationCommandAutocompleteDataOption
sourcefn eq(&self, other: &ApplicationCommandAutocompleteDataOption) -> bool
fn eq(&self, other: &ApplicationCommandAutocompleteDataOption) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ApplicationCommandAutocompleteDataOption) -> bool
fn ne(&self, other: &ApplicationCommandAutocompleteDataOption) -> bool
This method tests for !=.
impl Eq for ApplicationCommandAutocompleteDataOption
impl StructuralEq for ApplicationCommandAutocompleteDataOption
impl StructuralPartialEq for ApplicationCommandAutocompleteDataOption