pub struct ModalInteractionDataComponent {
pub custom_id: String,
pub kind: ComponentType,
pub value: String,
}Expand description
Data received when a user fills in a modal component.
Refer to the discord docs for more information.
Fields
custom_id: Stringkind: ComponentTypevalue: StringTrait Implementations
sourceimpl Clone for ModalInteractionDataComponent
impl Clone for ModalInteractionDataComponent
sourcefn clone(&self) -> ModalInteractionDataComponent
fn clone(&self) -> ModalInteractionDataComponent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ModalInteractionDataComponent
impl Debug for ModalInteractionDataComponent
sourceimpl<'de> Deserialize<'de> for ModalInteractionDataComponent
impl<'de> Deserialize<'de> for ModalInteractionDataComponent
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<ModalInteractionDataComponent> for ModalInteractionDataComponent
impl PartialEq<ModalInteractionDataComponent> for ModalInteractionDataComponent
sourcefn eq(&self, other: &ModalInteractionDataComponent) -> bool
fn eq(&self, other: &ModalInteractionDataComponent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ModalInteractionDataComponent) -> bool
fn ne(&self, other: &ModalInteractionDataComponent) -> bool
This method tests for !=.
impl Eq for ModalInteractionDataComponent
impl StructuralEq for ModalInteractionDataComponent
impl StructuralPartialEq for ModalInteractionDataComponent