pub struct ModalSubmitInteraction {
    pub application_id: Id<ApplicationMarker>,
    pub channel_id: Id<ChannelMarker>,
    pub data: ModalInteractionData,
    pub guild_id: Option<Id<GuildMarker>>,
    pub id: Id<InteractionMarker>,
    pub kind: InteractionType,
    pub member: Option<PartialMember>,
    pub token: String,
    pub user: Option<User>,
}
Information present in an Interaction::ModalSubmit.

Fields

application_id: Id<ApplicationMarker>

ID of the associated application.

channel_id: Id<ChannelMarker>

ID of the channel the interaction was triggered from.

data: ModalInteractionData

Data from the submitted modal.

guild_id: Option<Id<GuildMarker>>

ID of the guild the interaction was triggered from.

id: Id<InteractionMarker>

ID of the interaction.

kind: InteractionType

Type of the interaction.

member: Option<PartialMember>

Member that triggered the interaction.

Present when the command is used in a guild.

token: String

Token of the interaction.

user: Option<User>

User that triggered the interaction.

Present when the command is used in a direct message.

Implementations

ID of the user that submitted the modal.

This will first check for the member’s user’s ID and, if not present, then check the user’s ID.