Enum twilight_model::channel::message::sticker::StickerType
source · [−]#[repr(u8)]
pub enum StickerType {
Standard,
Guild,
}Expand description
Type of a Sticker.
Variants
Standard
Official sticker in a pack.
Part of nitro or in a removed purchasable pack.
Guild
Sticker uploaded to a boosted guild for the guild’s members.