Struct twilight_model::channel::message::sticker::MessageSticker
source · [−]pub struct MessageSticker {
pub format_type: StickerFormatType,
pub id: Id<StickerMarker>,
pub name: String,
}Expand description
Smallest amount of data required to render a sticker.
Fields
format_type: StickerFormatTypeid: Id<StickerMarker>name: StringTrait Implementations
sourceimpl Clone for MessageSticker
impl Clone for MessageSticker
sourcefn clone(&self) -> MessageSticker
fn clone(&self) -> MessageSticker
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for MessageSticker
impl Debug for MessageSticker
sourceimpl<'de> Deserialize<'de> for MessageSticker
impl<'de> Deserialize<'de> for MessageSticker
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for MessageSticker
impl Hash for MessageSticker
sourceimpl PartialEq<MessageSticker> for MessageSticker
impl PartialEq<MessageSticker> for MessageSticker
sourcefn eq(&self, other: &MessageSticker) -> bool
fn eq(&self, other: &MessageSticker) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &MessageSticker) -> bool
fn ne(&self, other: &MessageSticker) -> bool
This method tests for !=.
sourceimpl Serialize for MessageSticker
impl Serialize for MessageSticker
impl Eq for MessageSticker
impl StructuralEq for MessageSticker
impl StructuralPartialEq for MessageSticker