Struct twilight_model::channel::Attachment
source · [−]pub struct Attachment {
pub content_type: Option<String>,
pub ephemeral: bool,
pub filename: String,
pub description: Option<String>,
pub height: Option<u64>,
pub id: Id<AttachmentMarker>,
pub proxy_url: String,
pub size: u64,
pub url: String,
pub width: Option<u64>,
}Fields
content_type: Option<String>Attachment’s media type.
ephemeral: boolWhether this attachment is ephemeral.
Ephemeral attachments will automatically be removed after a set period of time. Ephemeral attachments on messages are guaranteed to be available as long as the message itself exists.
filename: Stringdescription: Option<String>height: Option<u64>id: Id<AttachmentMarker>proxy_url: Stringsize: u64url: Stringwidth: Option<u64>Trait Implementations
sourceimpl Clone for Attachment
impl Clone for Attachment
sourcefn clone(&self) -> Attachment
fn clone(&self) -> Attachment
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for Attachment
impl Debug for Attachment
sourceimpl<'de> Deserialize<'de> for Attachment
impl<'de> Deserialize<'de> for Attachment
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for Attachment
impl Hash for Attachment
sourceimpl PartialEq<Attachment> for Attachment
impl PartialEq<Attachment> for Attachment
sourcefn eq(&self, other: &Attachment) -> bool
fn eq(&self, other: &Attachment) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &Attachment) -> bool
fn ne(&self, other: &Attachment) -> bool
This method tests for !=.
sourceimpl Serialize for Attachment
impl Serialize for Attachment
impl Eq for Attachment
impl StructuralEq for Attachment
impl StructuralPartialEq for Attachment