Struct twilight_model::channel::FollowedChannel
source · [−]pub struct FollowedChannel {
pub channel_id: Id<ChannelMarker>,
pub webhook_id: Id<WebhookMarker>,
}Expand description
An object indicating that following a news channel was successful.
It contains the Id<ChannelMarker> that is being followed
and the Id<WebhookMarker> that was created in the
target channel.
Fields
channel_id: Id<ChannelMarker>webhook_id: Id<WebhookMarker>Trait Implementations
sourceimpl Clone for FollowedChannel
impl Clone for FollowedChannel
sourcefn clone(&self) -> FollowedChannel
fn clone(&self) -> FollowedChannel
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for FollowedChannel
impl Debug for FollowedChannel
sourceimpl<'de> Deserialize<'de> for FollowedChannel
impl<'de> Deserialize<'de> for FollowedChannel
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for FollowedChannel
impl Hash for FollowedChannel
sourceimpl PartialEq<FollowedChannel> for FollowedChannel
impl PartialEq<FollowedChannel> for FollowedChannel
sourcefn eq(&self, other: &FollowedChannel) -> bool
fn eq(&self, other: &FollowedChannel) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &FollowedChannel) -> bool
fn ne(&self, other: &FollowedChannel) -> bool
This method tests for !=.
sourceimpl Serialize for FollowedChannel
impl Serialize for FollowedChannel
impl Eq for FollowedChannel
impl StructuralEq for FollowedChannel
impl StructuralPartialEq for FollowedChannel