Struct twilight_model::channel::thread::ThreadsListing
source · [−]pub struct ThreadsListing {
pub has_more: Option<bool>,
pub members: Vec<ThreadMember>,
pub threads: Vec<Channel>,
}Expand description
Response body returned in thread listing methods.
Fields
has_more: Option<bool>Whether there are potentially more threads that could be returned.
members: Vec<ThreadMember>A thread member object for each returned thread the current user has joined.
threads: Vec<Channel>List of threads.