Struct twilight_model::gateway::presence::activity_button::ActivityButtonText
source · [−]pub struct ActivityButtonText {
pub label: String,
}Expand description
Button used in an activity without a URL.
serde
Textual activity buttons deserialize and serialize as a string. This means that a textual activity button with a label of “test” will serialize as simply the string “test” and vice versa.
use twilight_model::gateway::presence::activity_button::ActivityButtonText;
assert_eq!(
ActivityButtonText { label: "test".to_owned() },
serde_json::from_str(r#""test""#)?,
);Fields
label: StringText shown on the button.