Struct twilight_model::gateway::SessionStartLimit
source · [−]pub struct SessionStartLimit {
pub max_concurrency: u64,
pub remaining: u64,
pub reset_after: u64,
pub total: u64,
}Expand description
Current gateway session utilization status.
Fields
max_concurrency: u64Maximum number of session that may be started concurrently.
remaining: u64Number of remaining sessions for a given time period.
reset_after: u64When the remaining sessions resets back to the total.
total: u64Total number of sessions that can be started within the given time period.