Struct twilight_model::invite::WelcomeScreenChannel [−][src]
pub struct WelcomeScreenChannel {
pub channel_id: ChannelId,
pub description: String,
pub emoji_id: Option<EmojiId>,
pub emoji_name: Option<String>,
}Fields
channel_id: ChannelIdID of the channel.
description: StringDescription of the channel.
emoji_id: Option<EmojiId>ID of the emoji if the emoji is custom.
emoji_name: Option<String>Emoji’s name if it is custom, or the unicode character.