[−][src]Module twilight_model::user
Structs
| Connection | |
| CurrentUser | |
| CurrentUserGuild | Information about a guild the current user is in. |
| User | |
| UserFlags | |
| UserProfile |
Enums
| ConnectionVisibility | |
| PremiumType |
| Connection | |
| CurrentUser | |
| CurrentUserGuild | Information about a guild the current user is in. |
| User | |
| UserFlags | |
| UserProfile |
| ConnectionVisibility | |
| PremiumType |