Struct twilight_model::user::CurrentUser [−][src]
pub struct CurrentUser {
pub avatar: Option<String>,
pub bot: bool,
pub discriminator: String,
pub email: Option<String>,
pub flags: Option<UserFlags>,
pub id: UserId,
pub locale: Option<String>,
pub mfa_enabled: bool,
pub name: String,
pub premium_type: Option<PremiumType>,
pub public_flags: Option<UserFlags>,
pub verified: Option<bool>,
}Fields
avatar: Option<String>User’s avatar hash.
To retrieve the url to the avatar, you can follow Discord’s documentation on Image formatting.
bot: boolWhether the user belongs to an OAuth2 application.
discriminator: StringDiscriminator used to differentiate people with the same username.
serde
The discriminator field can be deserialized from either a string or an integer. The field will always serialize into a string due to that being the type Discord’s API uses.
email: Option<String>User’s email address associated to the account.
Requires the email oauth scope. See Discord’s documentation for
more information.
flags: Option<UserFlags>All flags on a user’s account.
id: UserIdUser’s id.
locale: Option<String>User’s chosen language option.
mfa_enabled: boolWhether the user has two factor enabled on their account.
name: StringUser’s username, not unique across the platform.
Type of Nitro subscription on a user’s account.
public_flags: Option<UserFlags>Public flags on a user’s account.
verified: Option<bool>Whether the email on this account has been verified.
Requires the email oauth scope. See Discord’s documentation for
more information.