Struct twilight_model::user::CurrentUserGuild
source · [−]pub struct CurrentUserGuild {
pub id: Id<GuildMarker>,
pub name: String,
pub icon: Option<ImageHash>,
pub owner: bool,
pub permissions: Permissions,
pub features: Vec<String>,
}Expand description
Information about a guild the current user is in.
This is a partial guild used for the Get Current User Guilds endpoint.
See Discord Docs/Get Current User Guilds.
Fields
id: Id<GuildMarker>Unique ID.
name: StringName of the guild.
The name must be at least 2 characters long and at most 100 characters long.
icon: Option<ImageHash>Hash of the icon.
owner: boolWhether the current user is the owner.
permissions: PermissionsPermissions of the current user in the guild. This excludes channels’ permission overwrites.
features: Vec<String>List of enabled guild features.