Struct twilight_model::user::UserProfile
source · [−]pub struct UserProfile {Show 13 fields
pub accent_color: Option<u64>,
pub avatar: Option<ImageHash>,
pub banner: Option<ImageHash>,
pub bot: bool,
pub discriminator: u16,
pub email: Option<String>,
pub flags: Option<UserFlags>,
pub id: Id<UserMarker>,
pub locale: Option<String>,
pub mfa_enabled: Option<bool>,
pub name: String,
pub premium_type: Option<PremiumType>,
pub verified: Option<bool>,
}Fields
accent_color: Option<u64>Accent color of the user’s banner.
This is an integer representation of a hexadecimal color code.
avatar: Option<ImageHash>Hash of the user’s banner image.
bot: booldiscriminator: u16Discriminator used to differentiate people with the same username.
serde
The discriminator field can be deserialized from either a string or an integer. The field will always serialize into a string due to that being the type Discord’s API uses.
email: Option<String>flags: Option<UserFlags>id: Id<UserMarker>locale: Option<String>mfa_enabled: Option<bool>name: Stringverified: Option<bool>Implementations
sourceimpl UserProfile
impl UserProfile
sourcepub const fn discriminator(&self) -> DiscriminatorDisplay
pub const fn discriminator(&self) -> DiscriminatorDisplay
Create a Display formatter for a user discriminator.