Struct twilight_model::voice::VoiceRegion
source · pub struct VoiceRegion {
pub custom: bool,
pub deprecated: bool,
pub id: String,
pub name: String,
pub optimal: bool,
}Expand description
Geographically based collection of voice servers.
Fields
custom: boolWhether this is a custom voice region, used for e.g. events.
deprecated: boolWhether this is a deprecated voice region (avoid switching to these).
id: StringUnique region identifier.
name: StringName of the region.
optimal: boolWhether this is the closest region to the current user’s client.