Module twilight_model::application::callback [−][src]
Used when responding to interactions.
Structs
| CallbackData | Optional extra data sent when responding to an |
Enums
| InteractionResponse | Payload used for responding to an interaction. |
| ResponseType | Contains the possible response type integers for an interaction. |