Struct twilight_model::application::interaction::application_command::ApplicationCommand [−][src]
pub struct ApplicationCommand {
pub application_id: ApplicationId,
pub channel_id: ChannelId,
pub data: CommandData,
pub guild_id: Option<GuildId>,
pub id: InteractionId,
pub kind: InteractionType,
pub member: Option<PartialMember>,
pub token: String,
pub user: Option<User>,
}Expand description
Data present in an Interaction of type ApplicationCommand.
Fields
application_id: ApplicationIdID of the associated application.
channel_id: ChannelIdThe channel the interaction was triggered from.
data: CommandDataData from the invoked command.
guild_id: Option<GuildId>ID of the guild the interaction was triggered from.
id: InteractionIdID of the interaction.
kind: InteractionTypeKind of the interaction.
member: Option<PartialMember>Member that triggered the interaction.
Present when the command is used in a guild.
token: StringToken of the interaction.
user: Option<User>User that triggered the interaction.
Present when the command is used in a direct message.