Struct twilight_model::user::UserProfile [−][src]
pub struct UserProfile {
pub avatar: Option<String>,
pub bot: bool,
pub discriminator: String,
pub email: Option<String>,
pub flags: Option<UserFlags>,
pub id: UserId,
pub locale: Option<String>,
pub mfa_enabled: Option<bool>,
pub name: String,
pub premium_type: Option<PremiumType>,
pub verified: Option<bool>,
}Fields
avatar: Option<String>bot: booldiscriminator: StringDiscriminator used to differentiate people with the same username.
serde
The discriminator field can be deserialized from either a string or an integer. The field will always serialize into a string due to that being the type Discord’s API uses.
email: Option<String>flags: Option<UserFlags>id: UserIdlocale: Option<String>mfa_enabled: Option<bool>name: Stringverified: Option<bool>Trait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.